@@ -193,7 +193,20 @@ do {                                                                          \
     PyModule_AddIntConstant(module, "OP_NETSCAPE_CA_DN_BUG", SSL_OP_NETSCAPE_CA_DN_BUG);
     PyModule_AddIntConstant(module, "OP_NETSCAPE_DEMO_CIPHER_CHANGE_BUG", SSL_OP_NETSCAPE_DEMO_CIPHER_CHANGE_BUG);
 
-	/* For SSL_set_shutdown */
+    /* DTLS related options.  The first two of these were introduced in
+     * 2005, the third in 2007.  To accomodate systems which are still using
+     * older versions, make them optional. */
+#ifdef SSL_OP_NO_QUERY_MTU
+    PyModule_AddIntConstant(module, "OP_NO_QUERY_MTU", SSL_OP_NO_QUERY_MTU);
+#endif
+#ifdef SSL_OP_COOKIE_EXCHANGE
+    PyModule_AddIntConstant(module, "OP_COOKIE_EXCHANGE", SSL_OP_COOKIE_EXCHANGE);
+#endif
+#ifdef SSL_OP_NO_TICKET
+    PyModule_AddIntConstant(module, "OP_NO_TICKET", SSL_OP_NO_TICKET);
+#endif
+
+    /* For SSL_set_shutdown */
     PyModule_AddIntConstant(module, "SENT_SHUTDOWN", SSL_SENT_SHUTDOWN);
     PyModule_AddIntConstant(module, "RECEIVED_SHUTDOWN", SSL_RECEIVED_SHUTDOWN);
 
